aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--acispy/spectrum.py12
1 files changed, 9 insertions, 3 deletions
diff --git a/acispy/spectrum.py b/acispy/spectrum.py
index 562e73e..6b4481c 100644
--- a/acispy/spectrum.py
+++ b/acispy/spectrum.py
@@ -27,18 +27,24 @@ class Spectrum:
self.EXPOSURE = self.header.get("EXPOSURE")
self.BACKSCAL = self.header.get("BACKSCAL")
- def calc_pb_flux(self, elow=9500, ehigh=12000):
+ def calc_flux(self, elow, ehigh):
"""
- Calculate the particle background flux:
+ Calculate the flux:
flux = counts / exposure / area
Parameters
----------
elow, ehigh : float, optional
Lower and upper energy limit for the particle background.
"""
chlow = ACIS.energy2channel(elow)
chhigh = ACIS.energy2channel(ehigh)
counts = self.counts[(chlow-1):chhigh].sum()
flux = counts / self.EXPOSURE / self.BACKSCAL
return flux
+
+ def calc_pb_flux(self, elow=9500, ehigh=12000):
+ """
+ Calculate the particle background (default: 9.5-12 keV) flux.
+ """
+ return self.calc_flux(elow=elow, ehigh=ehigh)
@@ -27,18 +27,24 @@ class Spectrum:
elow, ehigh : float, optional
- Lower and upper energy limit for the particle background.
+ Lower and upper energy limit to calculate the flux.
"""
chlow = ACIS.energy2channel(elow)